import { ContentObserver, ObserversModule } from '@angular/cdk/observers';
import { CommonModule } from '@angular/common';
import { InjectionToken, Component, ViewEncapsulation, ElementRef, Inject, Input, EventEmitter, Output, ViewChild, ContentChild, NgModule } from '@angular/core';
import { NtOverlayPosition, NtOverlayComponent, NtOverlayModule } from '@ng-tangram/components/overlay';
import { Subject } from 'rxjs';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { CdkOverlayOrigin } from '@angular/cdk/overlay';

const NT_DROPDOWN_PARENT_COMPONENT = new InjectionToken('nt-dropdown-parent-component');
class NtDropdownPaneComponent {
    constructor(_contentObserver, _elementRef, _parent) {
        this._contentObserver = _contentObserver;
        this._elementRef = _elementRef;
        this._parent = _parent;
        this._arrow = false;
        this._autosize = false;
        this.size = 'small';
        this.class = '';
        this._contentChange = new Subject();
    }
    set autosize(value) {
        this._autosize = coerceBooleanProperty(value);
    }
    get autosize() { return this._autosize; }
    set arrow(value) { this._arrow = coerceBooleanProperty(value); }
    get arrow() { return this._arrow; }
    get contentChanged() {
        return this._contentChange.asObservable();
    }
    get textContent() {
        return (this._elementRef.nativeElement.textContent || '').trim();
    }
    ngAfterContentInit() {
        this._contentSubscription = this._contentObserver
            .observe(this._elementRef)
            .subscribe(() => this._checkContentChange());
    }
    ngOnDestroy() {
        if (this._contentSubscription) {
            this._contentSubscription.unsubscribe();
        }
    }
    _checkContentChange() {
        if (this._parent.overlay.opened) {
            this._parent.overlay.forceUpdatePosition();
        }
    }
}
NtDropdownPaneComponent.decorators = [
    { type: Component, args: [{
                selector: 'nt-dropdown-pane, [nt-dropdown-pane]',
                template: '<ng-content></ng-content>',
                encapsulation: ViewEncapsulation.None,
                host: {
                    '[class]': '["nt-dropdown-pane", size, class].join(" ")',
                    '[class.autosize]': 'autosize'
                }
            },] }
];
NtDropdownPaneComponent.ctorParameters = () => [
    { type: ContentObserver },
    { type: ElementRef },
    { type: undefined, decorators: [{ type: Inject, args: [NT_DROPDOWN_PARENT_COMPONENT,] }] }
];
NtDropdownPaneComponent.propDecorators = {
    size: [{ type: Input }],
    class: [{ type: Input }],
    autosize: [{ type: Input }],
    arrow: [{ type: Input }]
};

class NtDropdownComponent {
    constructor(_elementRef) {
        this.position = NtOverlayPosition.BottomLeft;
        this.trigger = 'hover';
        this.afterOpen = new EventEmitter();
        this.afterClosed = new EventEmitter();
        this.beforeOpen = new EventEmitter();
        this.beforeClosed = new EventEmitter();
        this.positionChange = new EventEmitter();
        this.origin = new CdkOverlayOrigin(_elementRef);
    }
    _onClick(_) {
        if (this.trigger === 'click') {
            this.overlay.toggle();
        }
    }
    _onMouseEnter(_) {
        if (this.trigger === 'hover') {
            this.overlay.markOpen();
        }
    }
    _onMouseLeave(_) {
        if (this.trigger === 'hover') {
            this.overlay.markClose();
        }
    }
    _afterOpen(event) {
        this.afterOpen.next(event);
    }
    _afterClosed(event) {
        this.afterClosed.next(event);
    }
    _beforeOpen(event) {
        this.beforeOpen.next(event);
    }
    _beforeClosed(event) {
        this.beforeClosed.next(event);
    }
    _positionChange(change) {
        this.positionChange.next(change);
    }
}
NtDropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'nt-dropdown, [nt-dropdown]',
                template: "<ng-content></ng-content>\n<nt-overlay\n  overlayClass=\"nt-dropdown-overlay\"\n  [origin]=\"origin\"\n  [position]=\"position\"\n  [arrow]=\"pane?.arrow\"\n  (afterOpen)=\"_afterOpen($event)\"\n  (afterClosed)=\"_afterClosed($event)\"\n  (beforeOpen)=\"_beforeOpen($event)\"\n  (beforeClosed)=\"_beforeClosed($event)\"\n  (overlayEnter)=\"_onMouseEnter($event)\"\n  (overlayLeave)=\"_onMouseLeave($event)\"\n  (positionChange)=\"_positionChange($event)\">\n  <ng-content select=\"nt-dropdown-pane\"></ng-content>\n</nt-overlay>\n",
                encapsulation: ViewEncapsulation.None,
                host: {
                    '(click)': '_onClick($event)',
                    '(mouseenter)': '_onMouseEnter($event)',
                    '(mouseleave)': '_onMouseLeave($event)'
                },
                providers: [
                    { provide: NT_DROPDOWN_PARENT_COMPONENT, useExisting: NtDropdownComponent }
                ]
            },] }
];
NtDropdownComponent.ctorParameters = () => [
    { type: ElementRef }
];
NtDropdownComponent.propDecorators = {
    position: [{ type: Input }],
    trigger: [{ type: Input }],
    afterOpen: [{ type: Output }],
    afterClosed: [{ type: Output }],
    beforeOpen: [{ type: Output }],
    beforeClosed: [{ type: Output }],
    positionChange: [{ type: Output }],
    overlay: [{ type: ViewChild, args: [NtOverlayComponent, { static: true },] }],
    pane: [{ type: ContentChild, args: [NtDropdownPaneComponent,] }]
};

class NtDropdownModule {
}
NtDropdownModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ObserversModule,
                    NtOverlayModule
                ],
                exports: [
                    NtDropdownComponent,
                    NtDropdownPaneComponent
                ],
                declarations: [
                    NtDropdownComponent,
                    NtDropdownPaneComponent
                ]
            },] }
];

export { NT_DROPDOWN_PARENT_COMPONENT, NtDropdownComponent, NtDropdownModule, NtDropdownPaneComponent };
//# sourceMappingURL=dropdown.js.map
