import { isPlatformBrowser, CommonModule } from '@angular/common';
import { Component, ViewEncapsulation, Input, Directive, Inject, PLATFORM_ID, ElementRef, Renderer2, ComponentFactoryResolver, ViewContainerRef, NgModule } from '@angular/core';
import { trigger, transition } from '@angular/animations';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { fadeIn, fadeOut } from '@ng-tangram/components/core';

class NtScrimComponent {
    constructor() {
        this._isOpen = false;
        this.text = '';
    }
    set isOpen(value) { this._isOpen = coerceBooleanProperty(value); }
    get isOpen() { return this._isOpen; }
}
NtScrimComponent.decorators = [
    { type: Component, args: [{
                selector: '[nt-scrim], nt-scrim',
                template: "<div class=\"nt-scrim\" *ngIf=\"isOpen\" [@fade]>\n  <div class=\"nt-scrim-animation\">\n    <div class=\"nt-scrim-loading\"></div>\n  </div>\n  <h3 class=\"nt-scrim-text\">{{ text }}</h3>\n</div>\n",
                encapsulation: ViewEncapsulation.None,
                animations: [
                    trigger('fade', [
                        transition('void => *', fadeIn(.15)),
                        transition('* => void', fadeOut(.15))
                    ])
                ]
            },] }
];
NtScrimComponent.ctorParameters = () => [];
NtScrimComponent.propDecorators = {
    text: [{ type: Input }]
};

class NtScrimDirective {
    constructor(platformId, _elementRef, _renderer, _componentFactoryResolver, _viewContainerRef) {
        this.platformId = platformId;
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        this._componentFactoryResolver = _componentFactoryResolver;
        this._viewContainerRef = _viewContainerRef;
        const componentFactory = this._componentFactoryResolver.resolveComponentFactory(NtScrimComponent);
        this._componentRef = this._viewContainerRef.createComponent(componentFactory);
        if (isPlatformBrowser(this.platformId)) {
            const style = window.getComputedStyle(this._elementRef.nativeElement);
            if (style.position !== 'absolute' || style.position !== 'absolute') {
                this._renderer.setStyle(this._elementRef.nativeElement, 'position', 'relative');
            }
            this._renderer.appendChild(this._elementRef.nativeElement, this._componentRef.location.nativeElement);
        }
    }
    set text(value) { this._componentRef.instance.text = value; }
    set scrim(value) { this._componentRef.instance.isOpen = coerceBooleanProperty(value); }
    ngOnDestroy() {
        if (isPlatformBrowser(this.platformId)) {
            this._renderer.removeChild(this._elementRef.nativeElement, this._componentRef.location.nativeElement);
            this._componentRef.destroy();
        }
    }
}
NtScrimDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ntScrim]'
            },] }
];
NtScrimDirective.ctorParameters = () => [
    { type: Object, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] },
    { type: ElementRef },
    { type: Renderer2 },
    { type: ComponentFactoryResolver },
    { type: ViewContainerRef }
];
NtScrimDirective.propDecorators = {
    text: [{ type: Input, args: ['scrimText',] }],
    scrim: [{ type: Input, args: ['ntScrim',] }]
};

class NtScrimModule {
}
NtScrimModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                exports: [NtScrimComponent, NtScrimDirective],
                declarations: [NtScrimComponent, NtScrimDirective],
                entryComponents: [NtScrimComponent]
            },] }
];

export { NtScrimComponent, NtScrimDirective, NtScrimModule };
//# sourceMappingURL=scrim.js.map
