import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { EventEmitter, Component, ViewEncapsulation, ChangeDetectionStrategy, ChangeDetectorRef, Attribute, Self, Optional, Input, Output, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, NgControl } from '@angular/forms';
import { CommonModule } from '@angular/common';

let uniqueId = 0;
class NtSwitchChange {
    constructor(source, checked) {
        this.source = source;
        this.checked = checked;
    }
}
class NtSwitchComponent {
    constructor(_changeDetectorRef, tabIndex, ngControl) {
        this._changeDetectorRef = _changeDetectorRef;
        this.ngControl = ngControl;
        this.id = `nt-switch-${uniqueId++}`;
        this._disabled = false;
        this._checked = false;
        this._circle = false;
        this.change = new EventEmitter();
        this._onChange = () => { };
        this._onTouched = () => { };
        if (this.ngControl) {
            this.ngControl.valueAccessor = this;
        }
        this.tabIndex = parseInt(tabIndex) || 0;
    }
    get disabled() { return this._disabled; }
    set disabled(value) {
        if (value !== this.disabled) {
            this._disabled = coerceBooleanProperty(value);
            this._changeDetectorRef.markForCheck();
        }
    }
    get checked() { return this._checked; }
    set checked(value) {
        if (value !== this.checked) {
            this._checked = coerceBooleanProperty(value);
            this._changeDetectorRef.markForCheck();
        }
    }
    get circle() { return this._circle; }
    set circle(value) {
        if (value !== this.circle) {
            this._circle = coerceBooleanProperty(value);
        }
    }
    writeValue(value) {
        this._checked = !!value;
    }
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    _onInputClick(event) {
        event.stopPropagation();
        if (!this.disabled) {
            this._checked = !this._checked;
            this._onTouched();
            this._emitChangeEvent();
        }
    }
    _onInteractionEvent(event) {
        event.stopPropagation();
    }
    _emitChangeEvent() {
        const event = new NtSwitchChange(this, this.checked);
        this._onChange(this.checked);
        this.change.emit(event);
    }
}
NtSwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'nt-switch',
                template: "<input class=\"switch-input\" type=\"checkbox\"\n  [attr.id]=\"id\"\n  [tabIndex]=\"tabIndex\"\n  [checked]=\"checked\"\n  [disabled]=\"disabled\"\n  (change)=\"_onInteractionEvent($event)\"\n  (click)=\"_onInputClick($event)\">\n<label class=\"switch-paddle\" [attr.for]=\"id\"></label>\n",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    'class': 'switch nt-switch',
                    '[class.nt-switch-checked]': 'checked',
                    '[class.nt-switch-disabled]': 'disabled',
                    '[class.nt-switch-circle]': 'circle'
                },
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: NtSwitchComponent, multi: true }
                ]
            },] }
];
NtSwitchComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: String, decorators: [{ type: Attribute, args: ['tabindex',] }] },
    { type: NgControl, decorators: [{ type: Self }, { type: Optional }] }
];
NtSwitchComponent.propDecorators = {
    disabled: [{ type: Input }],
    checked: [{ type: Input }],
    circle: [{ type: Input }],
    change: [{ type: Output }]
};

class NtSwitchModule {
}
NtSwitchModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                exports: [NtSwitchComponent],
                declarations: [NtSwitchComponent]
            },] }
];

export { NtSwitchChange, NtSwitchComponent, NtSwitchModule };
//# sourceMappingURL=switch.js.map
