import { CommonModule } from '@angular/common';
import { EventEmitter, TemplateRef, Component, ViewEncapsulation, ElementRef, Input, Output, ViewChild, NgModule } from '@angular/core';
import { NtOverlayPosition, NtOverlayComponent, NtOverlayModule } from '@ng-tangram/components/overlay';
import { CdkOverlayOrigin } from '@angular/cdk/overlay';

class NtTooltipComponent {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        this._title = '';
        this.position = NtOverlayPosition.Top;
        this.afterOpen = new EventEmitter();
        this.afterClosed = new EventEmitter();
        this.beforeOpen = new EventEmitter();
        this.beforeClosed = new EventEmitter();
        this.positionChange = new EventEmitter();
        this.origin = new CdkOverlayOrigin(_elementRef);
    }
    set title(value) { this._title = value; }
    get title() { return this._title; }
    set template(value) { this._template = value; }
    get template() { return this._template; }
    set tooltip(value) {
        if (value instanceof TemplateRef) {
            this._template = value;
        }
        else {
            this._title = value;
            this._template = null;
        }
    }
    get _isDirective() {
        const attributes = this._elementRef.nativeElement.attributes;
        return attributes && attributes['nt-tooltip'];
    }
    ngOnChanges(changes) {
        const change = changes.title || changes.template || changes.tooltip;
        if (change && !change.firstChange) {
            Promise.resolve().then(() => {
                this.overlay.forceUpdatePosition();
            });
        }
    }
    _afterOpen(event) {
        this.afterOpen.next(event);
    }
    _afterClosed(event) {
        this.afterClosed.next(event);
    }
    _beforeOpen(event) {
        this.beforeOpen.next(event);
    }
    _beforeClosed(event) {
        this.beforeClosed.next(event);
    }
    _positionChange(change) {
        this.positionChange.next(change);
    }
}
NtTooltipComponent.decorators = [
    { type: Component, args: [{
                selector: 'nt-tooltip, [nt-tooltip]',
                template: "<ng-content></ng-content>\n<nt-overlay\n  overlayClass=\"nt-tootip-overlay\"\n  arrow\n  [origin]=\"origin\"\n  [position]=\"position\"\n  (afterOpen)=\"_afterOpen($event)\"\n  (afterClosed)=\"_afterClosed($event)\"\n  (beforeOpen)=\"_beforeOpen($event)\"\n  (beforeClosed)=\"_beforeClosed($event)\"\n  (overlayEnter)=\"overlay.markOpen()\"\n  (overlayLeave)=\"overlay.markClose()\"\n  (positionChange)=\"_positionChange($event)\">\n  <div class=\"nt-tooltip-content\" *ngIf=\"template\">\n    <ng-container *ngTemplateOutlet=\"template\"></ng-container>\n  </div>\n  <div class=\"nt-tooltip-content\" *ngIf=\"!template\" [innerHtml]=\"title\"></div>\n</nt-overlay>\n",
                encapsulation: ViewEncapsulation.None,
                host: {
                    'class': 'nt-tooltip',
                    '[class.nt-tooltip-trigger]': '!_isDirective',
                    '(mouseenter)': 'overlay.markOpen()',
                    '(mouseleave)': 'overlay.markClose()'
                }
            },] }
];
NtTooltipComponent.ctorParameters = () => [
    { type: ElementRef }
];
NtTooltipComponent.propDecorators = {
    title: [{ type: Input }],
    template: [{ type: Input }],
    tooltip: [{ type: Input, args: ['nt-tooltip',] }],
    position: [{ type: Input }],
    afterOpen: [{ type: Output }],
    afterClosed: [{ type: Output }],
    beforeOpen: [{ type: Output }],
    beforeClosed: [{ type: Output }],
    positionChange: [{ type: Output }],
    overlay: [{ type: ViewChild, args: [NtOverlayComponent, { static: true },] }]
};

class NtTooltipModule {
}
NtTooltipModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, NtOverlayModule],
                exports: [NtTooltipComponent],
                declarations: [NtTooltipComponent]
            },] }
];

export { NtTooltipComponent, NtTooltipModule };
//# sourceMappingURL=tooltip.js.map
